"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const themeTools_1 = require("./themeTools");
const syntax_1 = require("./syntax");
const css_1 = require("./css");
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const FileTools_1 = require("./FileTools");
const applicationDirectory = process.env.XDG_CONFIG_HOME !== undefined
    ? path_1.default.join(process.env.XDG_CONFIG_HOME, "hyper")
    : process.platform == "win32"
        ? path_1.default.join(process.env.APPDATA || "", "Hyper")
        : os_1.default.homedir();
exports.configDirectory = path_1.default.resolve(applicationDirectory, ".doki-theme-hyper-config");
const configFile = path_1.default.resolve(exports.configDirectory, ".hyper.doki.config.json");
exports.DEFAULT_CONFIGURATION = {
    themeId: "420b0ed5-803c-4127-97e3-dae6aa1a5972",
    showSticker: true,
    showWallpaper: true,
    stickerType: themeTools_1.StickerType.DEFAULT,
    useFonts: false,
};
exports.extractConfig = () => {
    if (!fs_1.default.existsSync(configFile)) {
        FileTools_1.createParentDirectories(configFile);
        fs_1.default.writeFileSync(configFile, JSON.stringify(exports.DEFAULT_CONFIGURATION), "utf8");
        return exports.DEFAULT_CONFIGURATION;
    }
    return JSON.parse(fs_1.default.readFileSync(configFile, "utf8"));
};
exports.saveConfig = (dokiConfig) => {
    fs_1.default.writeFileSync(configFile, JSON.stringify(dokiConfig), "utf8");
};
function getCorrectSticker(theme, stickerType) {
    const defaultSticker = theme.stickers.default;
    return stickerType === themeTools_1.StickerType.SECONDARY
        ? theme.stickers.secondary || defaultSticker
        : defaultSticker;
}
exports.getCorrectSticker = getCorrectSticker;
exports.getTheme = () => {
    const hyperDokiConfig = exports.extractConfig();
    const theme = themeTools_1.getThemeByName(hyperDokiConfig.themeId);
    const stickerType = hyperDokiConfig.stickerType;
    const sticker = getCorrectSticker(theme, stickerType);
    return {
        theme,
        sticker: {
            sticker,
            type: stickerType,
        },
    };
};
const getExtraSettings = () => {
    return exports.extractConfig().useFonts
        ? {
            fontFamily: '"Victor Mono", Menlo, "DejaVu Sans Mono", Consolas, "Lucida Console", monospace',
            fontWeight: "italic",
        }
        : {};
};
exports.decorateConfig = (config) => {
    const { theme: dokiTheme, sticker } = exports.getTheme();
    const syntax = syntax_1.constructSyntax(dokiTheme);
    const css = css_1.constructCSS(dokiTheme, sticker, config);
    return Object.assign({}, config, syntax, Object.assign(Object.assign({}, getExtraSettings()), { termCSS: config.termCSS || "", css: `${config.css || ""}
    ${css}
    ` }));
};
//# sourceMappingURL=config.js.map