"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const reducer_1 = require("./reducer");
const settings_1 = require("./settings");
const path_1 = __importDefault(require("path"));
const StickerUpdateService_1 = require("./StickerUpdateService");
const electron_1 = require("electron");
const passProps = (uid, parentProps, props) => Object.assign(props, {
    [reducer_1.THEME_STATE]: parentProps[reducer_1.THEME_STATE],
});
exports.mapTermsState = (state, map) => {
    return Object.assign(map, {
        [reducer_1.THEME_STATE]: state.ui[reducer_1.THEME_STATE],
    });
};
exports.mapHyperState = exports.mapTermsState;
exports.getTermGroupProps = passProps;
exports.getTermProps = passProps;
// eslint-disable-next-line @typescript-eslint/no-unused-vars
exports.decorateHyper = (Hyper) => class HyperDecorator extends react_1.Component {
    render() {
        return react_1.default.createElement(Hyper, Object.assign({}, this.props));
    }
};
exports.CONFIG_RELOAD = "CONFIG_RELOAD";
function reloadConfig(config) {
    const now = Date.now();
    return {
        type: exports.CONFIG_RELOAD,
        config,
        now,
    };
}
exports.reloadConfig = reloadConfig;
const createCacheBuster = () => new Date().valueOf().toString(32);
let initialized = false;
exports.decorateTerm = (Term) => {
    let cacheBuster = createCacheBuster();
    return class TerminalDecorator extends react_1.Component {
        constructor() {
            super(...arguments);
            this.state = {
                imageLoaded: false,
            };
        }
        static imageError() {
            cacheBuster = createCacheBuster();
        }
        static constructStickerUrl(themeState) {
            const localStickerPath = StickerUpdateService_1.resolveLocalStickerPath(themeState.currentSticker.sticker).replace(path_1.default.sep, "/");
            return `${localStickerPath}?time=${cacheBuster}`;
        }
        componentDidMount() {
            if (!initialized) {
                this.registerListener(settings_1.SET_THEME);
                this.registerListener(settings_1.SET_STICKER_TYPE);
                this.registerListener(settings_1.STICKER_UPDATED);
                this.registerListener(settings_1.TOGGLE_WALLPAPER);
                window.rpc.on(settings_1.TOGGLE_FONT, () => {
                    window.store.dispatch(reloadConfig(window.config.getConfig()));
                });
                electron_1.ipcRenderer.on(settings_1.STICKER_UPDATED, () => {
                    this.forceUpdate();
                    window.store.dispatch({
                        type: "RE_RENDER_PLZ",
                    });
                });
                window.rpc.on(settings_1.TOGGLE_STICKER, () => {
                    window.store.dispatch({
                        type: settings_1.TOGGLE_STICKER,
                    });
                });
                window.rpc.on(settings_1.TOGGLE_WALLPAPER, () => {
                    window.store.dispatch({
                        type: settings_1.TOGGLE_WALLPAPER,
                    });
                });
                initialized = true;
            }
        }
        registerListener(event) {
            window.rpc.on(event, (eventPayload) => {
                window.store.dispatch({
                    type: event,
                    payload: eventPayload,
                });
                window.store.dispatch(reloadConfig(window.config.getConfig()));
                electron_1.ipcRenderer.send(event, eventPayload);
            });
        }
        componentWillReceiveProps(nextProps) {
            const themeState = this.props[reducer_1.THEME_STATE];
            const nextThemeState = nextProps[reducer_1.THEME_STATE];
            if (themeState.currentSticker.sticker.path !==
                nextThemeState.currentSticker.sticker.path) {
                this.setState({ imageLoaded: false });
                cacheBuster = createCacheBuster();
            }
        }
        render() {
            const themeState = this.props[reducer_1.THEME_STATE];
            const imageStyle = window.screen.width <= 1920
                ? { maxHeight: "200px", maxWidth: "175px" }
                : {};
            return (react_1.default.createElement("div", { style: { width: "100%", height: "100%", position: "relative" } },
                react_1.default.createElement(Term, Object.assign({}, this.props)),
                react_1.default.createElement("div", { style: {
                        position: "absolute",
                        bottom: "0.5rem",
                        right: "0.5rem",
                        color: "black",
                    } }, themeState.showSticker ? (react_1.default.createElement("img", { style: this.state.imageLoaded ? imageStyle : { display: "none" }, onLoad: () => this.setLoaded(), onError: () => TerminalDecorator.imageError(), src: TerminalDecorator.constructStickerUrl(themeState), alt: themeState.currentSticker.sticker.name })) : (react_1.default.createElement(react_1.default.Fragment, null)))));
        }
        setLoaded() {
            this.setState({ imageLoaded: true });
        }
    };
};
//# sourceMappingURL=decorator.js.map